@@ -67,6 +67,7 @@ DBusMessage *device_create_bonding(struct btd_device *device,
 void device_remove_bondind(struct btd_device *device, DBusConnection *connection);
 void device_bonding_complete(struct btd_device *device, uint8_t status);
 void device_simple_pairing_complete(struct btd_device *device, uint8_t status);
+gboolean device_is_creating(struct btd_device *device, const char *sender);
 gboolean device_is_bonding(struct btd_device *device, const char *sender);
 void device_cancel_bonding(struct btd_device *device, uint8_t status);
 int device_request_authentication(struct btd_device *device, auth_type_t type,
@@ -81,9 +82,10 @@ void device_add_connection(struct btd_device *device, DBusConnection *conn,
 void device_remove_connection(struct btd_device *device, DBusConnection *conn,
 				uint16_t handle);
 gboolean device_has_connection(struct btd_device *device, uint16_t handle);
-void device_disconnect(struct btd_device *device);
+void device_request_disconnect(struct btd_device *device, DBusMessage *msg);
 
-typedef void (*disconnect_watch) (struct btd_device *device, void *user_data);
+typedef void (*disconnect_watch) (struct btd_device *device, gboolean removal,
+					void *user_data);
 
 guint device_add_disconnect_watch(struct btd_device *device,
 				disconnect_watch watch, void *user_data,
